@@ -30,9 +30,9 @@ class ScaleWithPolyAnnotation(Scale):
             rescaled_anno = []
 
             for point in anno:
-                rescaled_anno.append([point[0] / (width + 2*left_offset),point[0][1] / (height + 2*top_offset)])
+                rescaled_anno.append([point[0] / width * self.width + left_offset,point[1] / height * self.height + top_offset])
 
             ret_annotations.append(rescaled_anno)
 
 
-        return new_img,ret_annotations
\ No newline at end of file
+        return new_img,ret_annotations
